==> xcsoar-7.15.tar.xz: xcsoar-7.15/src/InfoBoxes/Content/Alternate.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_INFOBOX_CONTENT_ALTERNATE_HPP
#define XCSOAR_INFOBOX_CONTENT_ALTERNATE_HPP

#include "InfoBoxes/Content/Base.hpp"

class InfoBoxContentAlternateName : public InfoBoxContent
{
public:
  InfoBoxContentAlternateName(const unsigned _index) noexcept
    :index(_index) {}

  void Update(InfoBoxData &data) noexcept override;
  const InfoBoxPanel *GetDialogContent() noexcept override;

private:
  unsigned index;
};

class InfoBoxContentAlternateGR : public InfoBoxContent
{
public:
  InfoBoxContentAlternateGR(const unsigned _index) noexcept
    :index(_index) {}

  void Update(InfoBoxData &data) noexcept override;
  const InfoBoxPanel *GetDialogContent() noexcept override;

private:
  unsigned index;
};

#endif

==> xcsoar-7.27.tar.xz: xcsoar-7.27/src/InfoBoxes/Content/Alternate.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2022 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#pragma once

#include "InfoBoxes/Content/Base.hpp"

class InfoBoxContentAlternateName : public InfoBoxContent
{
public:
  InfoBoxContentAlternateName(const unsigned _index) noexcept
    :index(_index) {}

  void Update(InfoBoxData &data) noexcept override;
  const InfoBoxPanel *GetDialogContent() noexcept override;

private:
  unsigned index;
};

class InfoBoxContentAlternateGR : public InfoBoxContent
{
public:
  InfoBoxContentAlternateGR(const unsigned _index) noexcept
    :index(_index) {}

  void Update(InfoBoxData &data) noexcept override;
  const InfoBoxPanel *GetDialogContent() noexcept override;

private:
  unsigned index;
};
